# modelhouse

## Why?

**The purpose of `modelhouse` is to make it easy to distribute models to workers on cloud.**

With `modelhouse`, you can store and load your models from different storage backends (Google Cloud Storage, AWS S3, local). `modelhouse` also provides model caching, which can significantly reduce model loading time while keeping memory utilization low.

## Installation

```pip install modelhouse```

## Documentation
TODO

## Getting started
TODO
